@@ -13,14 +13,16 @@ Scenario:
   to buy tickets for that movie renege (leave queue).
 
 """
-import collections
+from __future__ import annotations
+
 import random
+from typing import Dict, List, NamedTuple, Optional
 
 import simpy
 
-
 RANDOM_SEED = 42
 TICKETS = 50  # Number of tickets per movie
+SELLOUT_THRESHOLD = 2  # Fewer tickets than this is a sellout
 SIM_TIME = 120  # Simulate until
 
 
@@ -38,7 +40,7 @@ def moviegoer(env, movie, num_tickets, theater):
 
     """
     with theater.counter.request() as my_turn:
-        # Wait until its our turn or until the movie is sold out
+        # Wait until it's our turn or until the movie is sold out
         result = yield my_turn | theater.sold_out[movie]
 
         # Check if it's our turn or if movie is sold out
@@ -54,7 +56,7 @@ def moviegoer(env, movie, num_tickets, theater):
 
         # Buy tickets
         theater.available[movie] -= num_tickets
-        if theater.available[movie] < 2:
+        if theater.available[movie] < SELLOUT_THRESHOLD:
             # Trigger the "sold out" event for the movie
             theater.sold_out[movie].succeed()
             theater.when_sold_out[movie] = env.now
@@ -73,9 +75,13 @@ def customer_arrivals(env, theater):
             env.process(moviegoer(env, movie, num_tickets, theater))
 
 
-Theater = collections.namedtuple('Theater', 'counter, movies, available, '
-                                            'sold_out, when_sold_out, '
-                                            'num_renegers')
+class Theater(NamedTuple):
+    counter: simpy.Resource
+    movies: List[str]
+    available: Dict[str, int]
+    sold_out: Dict[str, simpy.Event]
+    when_sold_out: Dict[str, Optional[float]]
+    num_renegers: Dict[str, int]
 
 
 # Setup and start the simulation
@@ -84,14 +90,15 @@ random.seed(RANDOM_SEED)
 env = simpy.Environment()
 
 # Create movie theater
-counter = simpy.Resource(env, capacity=1)
 movies = ['Python Unchained', 'Kill Process', 'Pulp Implementation']
-available = {movie: TICKETS for movie in movies}
-sold_out = {movie: env.event() for movie in movies}
-when_sold_out = {movie: None for movie in movies}
-num_renegers = {movie: 0 for movie in movies}
-theater = Theater(counter, movies, available, sold_out, when_sold_out,
-                  num_renegers)
+theater = Theater(
+    counter=simpy.Resource(env, capacity=1),
+    movies=movies,
+    available={movie: TICKETS for movie in movies},
+    sold_out={movie: env.event() for movie in movies},
+    when_sold_out={movie: None for movie in movies},
+    num_renegers={movie: 0 for movie in movies},
+)
 
 # Start process and run
 env.process(customer_arrivals(env, theater))
@@ -100,7 +107,10 @@ env.run(until=SIM_TIME)
 # Analysis/results
 for movie in movies:
     if theater.sold_out[movie]:
-        print('Movie "%s" sold out %.1f minutes after ticket counter '
-              'opening.' % (movie, theater.when_sold_out[movie]))
-        print('  Number of people leaving queue when film sold out: %s' %
-              theater.num_renegers[movie])
+        sellout_time = theater.when_sold_out[movie]
+        num_renegers = theater.num_renegers[movie]
+        print(
+            f'Movie "{movie}" sold out {sellout_time:.1f} minutes '
+            f'after ticket counter opening.'
+        )
+        print(f'  Number of people leaving queue when film sold out: {num_renegers}')
