@@ -1,7 +1,9 @@
 """
-SimPy specific exeptions.
+SimPy specific exceptions.
 
 """
+from __future__ import annotations
+
 from typing import Any, Optional
 
 
