@@ -6,7 +6,7 @@ Theses test cases demonstrate the API for shared resources.
 import pytest
 
 import simpy
-
+from simpy.resources.resource import Preempted
 
 #
 # Tests for Resource
@@ -19,6 +19,7 @@ def test_resource(env, log):
     at a gas station).
 
     """
+
     def pem(env, name, resource, log):
         req = resource.request()
         yield req
@@ -40,12 +41,14 @@ def test_resource(env, log):
 
 
 def test_resource_capacity(env):
-    pytest.raises(ValueError, simpy.Resource, env, 0)
+    with pytest.raises(ValueError, match=r'"capacity" must be > 0.'):
+        simpy.Resource(env, 0)
 
 
 def test_resource_context_manager(env, log):
     """The event that ``Resource.request()`` returns can be used as
     Context Manager."""
+
     def pem(env, name, resource, log):
         with resource.request() as request:
             yield request
@@ -73,21 +76,31 @@ def test_resource_slots(env, log):
         env.process(pem(env, str(i), resource, log))
     env.run()
 
-    assert log == [('0', 0), ('1', 0), ('2', 0), ('3', 1), ('4', 1), ('5', 1),
-                   ('6', 2), ('7', 2), ('8', 2)]
+    assert log == [
+        ('0', 0),
+        ('1', 0),
+        ('2', 0),
+        ('3', 1),
+        ('4', 1),
+        ('5', 1),
+        ('6', 2),
+        ('7', 2),
+        ('8', 2),
+    ]
 
 
 def test_resource_continue_after_interrupt(env):
     """A process may be interrupted while waiting for a resource but
     should be able to continue waiting afterwards."""
+
     def pem(env, res):
         with res.request() as req:
             yield req
             yield env.timeout(1)
 
     def victim(env, res):
+        evt = res.request()
         try:
-            evt = res.request()
             yield evt
             pytest.fail('Should not have gotten the resource.')
         except simpy.Interrupt:
@@ -95,7 +108,7 @@ def test_resource_continue_after_interrupt(env):
             res.release(evt)
             assert env.now == 1
 
-    def interruptor(env, proc):
+    def interruptor(proc):
         proc.interrupt()
         return 0
         yield
@@ -103,29 +116,30 @@ def test_resource_continue_after_interrupt(env):
     res = simpy.Resource(env, 1)
     env.process(pem(env, res))
     proc = env.process(victim(env, res))
-    env.process(interruptor(env, proc))
+    env.process(interruptor(proc))
     env.run()
 
 
 def test_resource_release_after_interrupt(env):
-    """A process needs to release a resource, even it it was interrupted
+    """A process needs to release a resource, even if it was interrupted
     and does not continue to wait for it."""
+
     def blocker(env, res):
         with res.request() as req:
             yield req
             yield env.timeout(1)
 
     def victim(env, res):
+        evt = res.request()
         try:
-            evt = res.request()
             yield evt
             pytest.fail('Should not have gotten the resource.')
         except simpy.Interrupt:
-            # Dont wait for the resource
+            # Don't wait for the resource
             res.release(evt)
             assert env.now == 0
 
-    def interruptor(env, proc):
+    def interruptor(proc):
         proc.interrupt()
         return 0
         yield
@@ -133,16 +147,17 @@ def test_resource_release_after_interrupt(env):
     res = simpy.Resource(env, 1)
     env.process(blocker(env, res))
     victim_proc = env.process(victim(env, res))
-    env.process(interruptor(env, victim_proc))
+    env.process(interruptor(victim_proc))
     env.run()
 
 
 def test_resource_immediate_requests(env):
     """A process must not acquire a resource if it releases it and immediately
     requests it again while there are already other requesting processes."""
+
     def child(env, res):
         result = []
-        for i in range(3):
+        for _ in range(3):
             with res.request() as req:
                 yield req
                 result.append(env.now)
@@ -166,16 +181,15 @@ def test_resource_immediate_requests(env):
 
 def test_resource_cm_exception(env, log):
     """Resource with context manager receives an exception."""
+
     def process(env, resource, log, raise_):
-        try:
-            with resource.request() as req:
-                yield req
-                yield env.timeout(1)
-                log.append(env.now)
-                if raise_:
+        with resource.request() as req:
+            yield req
+            yield env.timeout(1)
+            log.append(env.now)
+            if raise_:
+                with pytest.raises(ValueError, match='Foo'):
                     raise ValueError('Foo')
-        except ValueError as err:
-            assert err.args == ('Foo',)
 
     resource = simpy.Resource(env, 1)
     env.process(process(env, resource, log, True))
@@ -219,19 +233,16 @@ def test_sorted_queue_maxlen(env):
     """Requests must fail if more than *maxlen* requests happen
     concurrently."""
     resource = simpy.PriorityResource(env, capacity=1)
-    resource.put_queue.maxlen = 1
+    resource.put_queue.maxlen = 1  # pyright: ignore
 
     def process(env, resource):
         # The first request immediately triggered and does not enter the queue.
         resource.request(priority=1)
         # The second request is enqueued.
         resource.request(priority=1)
-        try:
+        with pytest.raises(RuntimeError, match='Cannot append event. Queue is full.'):
             # The third request will now fail.
             resource.request(priority=1)
-            pytest.fail('Expected a RuntimeError')
-        except RuntimeError as e:
-            assert e.args[0] == 'Cannot append event. Queue is full.'
         yield env.timeout(0)
 
     env.process(process(env, resource))
@@ -245,7 +256,7 @@ def test_get_users(env):
             yield env.timeout(1)
 
     resource = simpy.Resource(env, 1)
-    procs = [env.process(process(env, resource)) for i in range(3)]
+    procs = [env.process(process(env, resource)) for _ in range(3)]
     env.run(until=1)
     assert [evt.proc for evt in resource.users] == procs[0:1]
     assert [evt.proc for evt in resource.queue] == procs[1:]
@@ -263,7 +274,7 @@ def test_preemptive_resource(env):
     processes. Note that higher priorities are indicated by a lower number
     value."""
 
-    def proc_a(env, resource, prio):
+    def proc_a(_, resource, prio):
         try:
             with resource.request(priority=prio) as req:
                 yield req
@@ -271,7 +282,7 @@ def test_preemptive_resource(env):
         except simpy.Interrupt:
             pass
 
-    def proc_b(env, resource, prio):
+    def proc_b(_, resource, prio):
         with resource.request(priority=prio) as req:
             yield req
 
@@ -293,7 +304,7 @@ def test_preemptive_resource_timeout_0(env):
                 pass
         yield env.event()
 
-    def proc_b(env, resource, prio):
+    def proc_b(_, resource, prio):
         with resource.request(priority=prio) as req:
             yield req
 
@@ -313,6 +324,8 @@ def test_mixed_preemption(env, log):
                 yield env.timeout(2)
                 log.append((env.now, id))
             except simpy.Interrupt as ir:
+                assert ir is not None  # noqa: PT017
+                assert isinstance(ir.cause, Preempted)  # noqa: PT017
                 log.append((env.now, id, (ir.cause.by, ir.cause.usage_since)))
 
     res = simpy.PreemptiveResource(env, 1)
@@ -330,11 +343,11 @@ def test_mixed_preemption(env, log):
     env.run()
 
     assert log == [
-        (2, 0),           # p0 done
+        (2, 0),  # p0 done
         (3, 2, (p3, 2)),  # p2 got it next, but got interrupted by p3
-        (5, 3),           # p3 done
-        (7, 1),           # p1 done (finally got the resource)
-        (9, 4),           # p4 done
+        (5, 3),  # p3 done
+        (7, 1),  # p1 done (finally got the resource)
+        (9, 4),  # p4 done
     ]
 
 
@@ -347,6 +360,7 @@ def test_nested_preemption(env, log):
                 yield env.timeout(5)
                 log.append((env.now, id))
             except simpy.Interrupt as ir:
+                assert isinstance(ir.cause, Preempted)  # noqa: PT017
                 log.append((env.now, id, (ir.cause.by, ir.cause.usage_since)))
 
     def process2(id, env, res0, res1, delay, prio, preempt, log):
@@ -360,12 +374,23 @@ def test_nested_preemption(env, log):
                         yield env.timeout(5)
                         log.append((env.now, id))
                     except simpy.Interrupt as ir:
-                        log.append((env.now, id, (ir.cause.by,
-                                                  ir.cause.usage_since,
-                                                  ir.cause.resource)))
+                        assert isinstance(ir.cause, Preempted)  # noqa: PT017
+                        log.append(
+                            (
+                                env.now,
+                                id,
+                                (ir.cause.by, ir.cause.usage_since, ir.cause.resource),
+                            )
+                        )
             except simpy.Interrupt as ir:
-                log.append((env.now, id, (ir.cause.by, ir.cause.usage_since,
-                                          ir.cause.resource)))
+                assert isinstance(ir.cause, Preempted)  # noqa: PT017
+                log.append(
+                    (
+                        env.now,
+                        id,
+                        (ir.cause.by, ir.cause.usage_since, ir.cause.resource),
+                    )
+                )
 
     res0 = simpy.PreemptiveResource(env, 1)
     res1 = simpy.PreemptiveResource(env, 1)
@@ -384,23 +409,26 @@ def test_nested_preemption(env, log):
         (1, 0, (p1, 0, res1)),
         (6, 1),
         (21, 2, (p3, 20, res0)),
-        (26, 3), (31, 4),
+        (26, 3),
+        (31, 4),
     ]
 
+
 #
 # Tests for Container
 #
 
 
 def test_container(env, log):
-    """A *container* is a resource (of optinally limited capacity) where
-    you can put in our take out a discrete or continuous amount of
+    """A *container* is a resource (of optionally limited capacity) where
+    you can put in our take-out a discrete or continuous amount of
     things (e.g., a box of lump sugar or a can of milk).  The *put* and
     *get* operations block if the buffer is to full or to empty. If they
-    return, the process nows that the *put* or *get* operation was
-    successfull.
+    return, the process knows that the *put* or *get* operation was
+    successful.
 
     """
+
     def putter(env, buf, log):
         yield env.timeout(1)
         while True:
@@ -452,19 +480,24 @@ def test_initial_container_capacity(env):
 
 def test_container_get_put_bounds(env):
     container = simpy.Container(env)
-    pytest.raises(ValueError, container.get, -13)
-    pytest.raises(ValueError, container.put, -13)
+    with pytest.raises(ValueError, match='amount.*must be > 0'):
+        container.get(-13)
+    with pytest.raises(ValueError, match='amount.*must be > 0'):
+        container.put(-13)
 
 
-@pytest.mark.parametrize(('error', 'args'), [
-    (None, [2, 1]),  # normal case
-    (None, [1, 1]),  # init == capacity should be valid
-    (None, [1, 0]),  # init == 0 should be valid
-    (ValueError, [1, 2]),  # init > capcity
-    (ValueError, [0]),  # capacity == 0
-    (ValueError, [-1]),  # capacity < 0
-    (ValueError, [1, -1]),  # init < 0
-])
+@pytest.mark.parametrize(
+    ('error', 'args'),
+    [
+        (None, [2, 1]),  # normal case
+        (None, [1, 1]),  # init == capacity should be valid
+        (None, [1, 0]),  # init == 0 should be valid
+        (ValueError, [1, 2]),  # init > capacity
+        (ValueError, [0]),  # capacity == 0
+        (ValueError, [-1]),  # capacity < 0
+        (ValueError, [1, -1]),  # init < 0
+    ],
+)
 def test_container_init_capacity(env, error, args):
     args.insert(0, env)
     if error:
@@ -481,14 +514,15 @@ def test_container_init_capacity(env, error, args):
 def test_store(env):
     """A store models the production and consumption of concrete python
     objects (in contrast to containers, where you only now if the *put*
-    or *get* operations were successfull but don't get concrete
+    or *get* operations were successful but don't get concrete
     objects).
 
     """
-    def putter(env, store, item):
+
+    def putter(_, store, item):
         yield store.put(item)
 
-    def getter(env, store, orig_item):
+    def getter(_, store, orig_item):
         item = yield store.get()
         assert item is orig_item
 
@@ -501,22 +535,27 @@ def test_store(env):
     env.run()
 
 
-@pytest.mark.parametrize('Store', [
-    simpy.Store,
-    simpy.FilterStore,
-])
-def test_initial_store_capacity(env, Store):
-    store = Store(env)
+@pytest.mark.parametrize(
+    'store_type',
+    [
+        simpy.Store,
+        simpy.FilterStore,
+    ],
+)
+def test_initial_store_capacity(env, store_type):
+    store = store_type(env)
     assert store.capacity == float('inf')
 
 
 def test_store_capacity(env):
-    pytest.raises(ValueError, simpy.Store, env, 0)
-    pytest.raises(ValueError, simpy.Store, env, -1)
+    with pytest.raises(ValueError, match='"capacity" must be > 0'):
+        simpy.Store(env, 0)
+    with pytest.raises(ValueError, match='"capacity" must be > 0'):
+        simpy.Store(env, -1)
 
     capacity = 2
     store = simpy.Store(env, capacity)
-    env.process((store.put(i) for i in range(capacity + 1)))
+    env.process(store.put(i) for i in range(capacity + 1))
     env.run()
 
     # Ensure store is filled to capacity
@@ -546,7 +585,7 @@ def test_priority_store_item_priority(env):
 
     # Do not specify priority; the items themselves will be compared to
     # determine priority.
-    env.process((pstore.put(s) for s in 'bcadefg'))
+    env.process(pstore.put(s) for s in 'bcadefg')
     env.process(getter(1))
     env.process(getter(2))
     env.process(getter(3))
@@ -566,7 +605,7 @@ def test_priority_store_stable_order(env):
     items = [object() for _ in range(3)]
 
     # Unorderable items are inserted with same priority.
-    env.process((pstore.put(simpy.PriorityItem(0, item)) for item in items))
+    env.process(pstore.put(simpy.PriorityItem(0, item)) for item in items)
     env.process(getter(1))
     env.process(getter(2))
     env.process(getter(3))
@@ -598,6 +637,7 @@ def test_filter_store_get_after_mismatch(env):
     first mismatch.
 
     """
+
     def putter(env, store):
         # The order of putting 'spam' before 'eggs' is important here.
         yield store.put('spam')
@@ -610,7 +650,8 @@ def test_filter_store_get_after_mismatch(env):
         spam = store.get(lambda i: i == 'spam')
 
         ret = yield spam | eggs
-        assert spam in ret and eggs not in ret
+        assert spam in ret
+        assert eggs not in ret
         assert env.now == 0
 
         yield eggs
@@ -670,12 +711,14 @@ def test_filter_calls_worst_case(env):
 
     # The filter function is repeatedly called for every item in the store
     # until a match is found.
+    # fmt: off
     assert log == [
         'put 0', 'check 0',
         'put 1', 'check 0', 'check 1',
         'put 2', 'check 0', 'check 1', 'check 2',
         'put 3', 'check 0', 'check 1', 'check 2', 'check 3', 'get 3',
     ]
+    # fmt: on
 
 
 def test_immediate_put_request(env):
